StateValueEstimator

Trait StateValueEstimator 

pub trait StateValueEstimator<D: Domain>: Send {
    // Required method
    fn estimate(
        &mut self,
        rnd: &mut ChaCha8Rng,
        config: &MCTSConfiguration,
        initial_state: &D::State,
        start_tick: u64,
        node: &Node<D>,
        edges: &Edges<D>,
        depth: u32,
    ) -> Option<BTreeMap<AgentId, f32>>;
}
An estimator of state-value function.

Required Methods

fn estimate( &mut self, rnd: &mut ChaCha8Rng, config: &MCTSConfiguration, initial_state: &D::State, start_tick: u64, node: &Node<D>, edges: &Edges<D>, depth: u32, ) -> Option<BTreeMap<AgentId, f32>>

Takes the state of an explored node and returns the estimated expected (discounted) values.

Returns None if the passed node has no unexpanded edge.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors