pub trait DomainWithPlanningTask: Domain {
// Provided method
fn fallback_task(_agent: AgentId) -> Box<dyn Task<Self>> { ... }
}Expand description
Domains who want to use planning tasks must implement this.
Provided Methods
Sourcefn fallback_task(_agent: AgentId) -> Box<dyn Task<Self>>
fn fallback_task(_agent: AgentId) -> Box<dyn Task<Self>>
A fallback task, in case, during planning, the world evolved in a different direction than what the MCTS tree explored.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".